@@ -1,6 +1,5 @@
 
 using System;
-using System.Collections;
 using System.Collections.Generic;
 using System.Runtime.InteropServices;
 using System.Text;
@@ -40,6 +39,7 @@ namespace Tomboy
 			this.note = note;
 			this.IconName = "tomboy";
 			this.SetDefaultSize (450, 360);
+			Resizable = true;
 
 			accel_group = new Gtk.AccelGroup ();
 			AddAccelGroup (accel_group);
@@ -200,7 +200,7 @@ namespace Tomboy
 			Move (x, y);
 		}
 
-		void OnEscapeSettingChanged (object sender, GConf.NotifyEventArgs args)
+		void OnEscapeSettingChanged (object sender, NotifyEventArgs args)
 		{
 			// enable escape key
 			if ((bool) args.Value)
@@ -242,6 +242,9 @@ namespace Tomboy
 
 		void CloseAllWindowsHandler (object sender, EventArgs args)
 		{
+#if WIN32 || MAC
+			Tomboy.Exit (0);
+#else
 			int workspace = tomboy_window_get_workspace (note.Window.Handle);
 
 			foreach (Note iter in note.Manager.Notes) {
@@ -255,6 +258,7 @@ namespace Tomboy
 					iter.Window.CloseWindowHandler (null, null);
 				}
 			}
+#endif
 		}
 
 		//
@@ -718,7 +722,7 @@ namespace Tomboy
 		Gtk.Button next_button;
 		Gtk.Button prev_button;
 
-		ArrayList current_matches;
+		List<Match> current_matches;
 		string prev_search_text;
 
 		InterruptableTimeout entry_changed_timeout;
@@ -1101,9 +1105,9 @@ namespace Tomboy
 			UpdateSensitivity ();
 		}
 
-		ArrayList FindMatchesInBuffer (NoteBuffer buffer, string [] words)
+		List<Match> FindMatchesInBuffer (NoteBuffer buffer, string [] words)
 		{
-			ArrayList matches = new ArrayList ();
+			List<Match> matches = new List<Match> ();
 
 			string note_text = buffer.GetSlice (buffer.StartIter,
 			                                    buffer.EndIter,
