@@ -145,6 +145,8 @@ namespace Tomboy
 			Pixbuf = GuiUtils.GetIcon ("tomboy", panel_size);
 
 			Tooltip = TomboyTrayUtils.GetToolTipText ();
+
+			Tomboy.ExitingEvent += OnExit;
 #if MAC
 			Visible = false;
 #endif
@@ -195,13 +197,13 @@ namespace Tomboy
 			
 			Gdk.Screen screen;
 			Gdk.Rectangle area;
-			Gtk.Orientation orientation;
 			try {
 #if WIN32 || MAC
 				menu.Screen.Display.GetPointer (out x, out y);
 				screen = menu.Screen;
 				area.Height = 0;
 #else
+				Gtk.Orientation orientation;
 				GetGeometry (out screen, out area, out orientation);
 				x = area.X;
 				y = area.Y;
@@ -272,19 +274,23 @@ namespace Tomboy
 			Tomboy.ActionManager ["QuitTomboyAction"].Activate ();
 		}
 
+		void OnExit (object sender, EventArgs e)
+		{
+			Visible = false;
+		}
+
 		public bool MenuOpensUpward ()
 		{
 			bool open_upwards = false;
 			int val = 0;
 			Gdk.Screen screen = null;
-
-			Gdk.Rectangle area;
-			Gtk.Orientation orientation;
 #if WIN32 || MAC
 			int x;
 			tray.TomboyTrayMenu.Screen.Display.GetPointer (out x, out val);
 			screen = tray.TomboyTrayMenu.Screen;
 #else
+			Gdk.Rectangle area;
+			Gtk.Orientation orientation;
 			GetGeometry (out screen, out area, out orientation);
 			val = area.Y;
 #endif
@@ -349,7 +355,7 @@ namespace Tomboy
 				if (item != null)
 					GConfKeybindingToAccel.AddAccelerator (
 					        item,
-					        Preferences.KEYBINDING_CREATE_NEW_NOTE);
+					        Preferences.KEYBINDING_OPEN_RECENT_CHANGES);
 
 				// Open Start Here Keybinding
 				item =
@@ -358,7 +364,7 @@ namespace Tomboy
 				if (item != null)
 					GConfKeybindingToAccel.AddAccelerator (
 					        item,
-					        Preferences.KEYBINDING_OPEN_RECENT_CHANGES);
+					        Preferences.KEYBINDING_OPEN_START_HERE);
 			}
 
 			return menu;
@@ -460,9 +466,9 @@ namespace Tomboy
 				recent_notes.Add (item);
 
 				list_size++;
-
+				
 				bool enable_keybindings = (bool)
-				                          Preferences.Get (Preferences.ENABLE_KEYBINDINGS);
+					                  Preferences.Get (Preferences.ENABLE_KEYBINDINGS);
 				if (enable_keybindings)
 					GConfKeybindingToAccel.AddAccelerator (
 					        item,
@@ -573,11 +579,11 @@ namespace Tomboy
 
 				return binding;
 			} catch {
-			return null;
+				return null;
+			}
 		}
-	}
 
-	public static void AddAccelerator (Gtk.MenuItem item, string gconf_path)
+		public static void AddAccelerator (Gtk.MenuItem item, string gconf_path)
 		{
 			uint keyval;
 			Gdk.ModifierType mods;
